@@ -382,7 +382,7 @@ int taskent_send_signal(int signum)
 	user_count = 0;
 	g_taskent_for_each(te) {
 		sprintf(fn, "%s/dsptask%d/proc_list", sys_dsp_dir, te->minor);
-		if ((fp_pl = fopen(fn, "r")) < 0)
+		if (NULL == (fp_pl = fopen(fn, "r")))
 			continue;
 		while (fscanf(fp_pl, "%d", &pid) > 0) {
 			user_count++;
@@ -401,7 +401,7 @@ int taskent_send_signal(int signum)
 		user_count = 0;
 		g_taskent_for_each(te) {
 			sprintf(fn, "%s/dsptask%d/proc_list", sys_dsp_dir, te->minor);
-			if ((fp_pl = fopen(fn, "r")) < 0)
+			if (NULL == (fp_pl = fopen(fn, "r")))
 				continue;
 			if (fscanf(fp_pl, "%d", &pid) > 0)
 				user_count++;
