@@ -551,7 +551,7 @@ static int static_task_send_signal(int n, int signum)
 	user_count = 0;
 	for (t = 0; t < n; t++) {
 		sprintf(fn, "%s/dsptask%d/proc_list", sys_dsp_dir, t);
-		if ((fp_pl = fopen(fn, "r")) < 0)
+		if (NULL == (fp_pl = fopen(fn, "r")))
 			continue;
 		while (fscanf(fp_pl, "%d", &pid) > 0) {
 			user_count++;
@@ -570,7 +570,7 @@ static int static_task_send_signal(int n, int signum)
 		user_count = 0;
 		for (t = 0; t < n; t++) {
 			sprintf(fn, "%s/dsptask%d/proc_list", sys_dsp_dir, t);
-			if ((fp_pl = fopen(fn, "r")) < 0)
+			if (NULL == (fp_pl = fopen(fn, "r")))
 				continue;
 			if (fscanf(fp_pl, "%d", &pid) > 0)
 				user_count++;
